==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebNumberFilteringOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOperandDescriptionMetadata } from "./WebFilteringOperandDescriptionMetadata";
import { WebNumberFilteringOperandDescription } from "./WebNumberFilteringOperandDescription";
/**
 * @hidden
 */
export let WebNumberFilteringOperandDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebNumberFilteringOperandDescriptionMetadata extends Base {
        static b(a) {
            if (WebNumberFilteringOperandDescriptionMetadata.a == null) {
                WebNumberFilteringOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebNumberFilteringOperandDescriptionMetadata.c(WebNumberFilteringOperandDescriptionMetadata.a);
            }
            if (a.k(WebNumberFilteringOperandDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebNumberFilteringOperandDescriptionMetadata.a);
        }
        static c(a) {
            WebFilteringOperandDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:NumberFilteringOperand");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebNumberFilteringOperandDescriptionMetadata.b(a);
            a.ad("WebNumberFilteringOperand", () => new WebNumberFilteringOperandDescription());
            a.ac("WebNumberFilteringOperand", WebNumberFilteringOperandDescriptionMetadata.a);
        }
    }
    WebNumberFilteringOperandDescriptionMetadata.$t = markType(WebNumberFilteringOperandDescriptionMetadata, 'WebNumberFilteringOperandDescriptionMetadata');
    WebNumberFilteringOperandDescriptionMetadata.a = null;
    return WebNumberFilteringOperandDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebNumberFilteringOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOperandDescriptionMetadata } from "./WebFilteringOperandDescriptionMetadata";
import { WebNumberFilteringOperandDescription } from "./WebNumberFilteringOperandDescription";
/**
 * @hidden
 */
export let WebNumberFilteringOperandDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebNumberFilteringOperandDescriptionMetadata extends Base {
        static b(a) {
            if (WebNumberFilteringOperandDescriptionMetadata.a == null) {
                WebNumberFilteringOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebNumberFilteringOperandDescriptionMetadata.c(WebNumberFilteringOperandDescriptionMetadata.a);
            }
            if (a.k(WebNumberFilteringOperandDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebNumberFilteringOperandDescriptionMetadata.a);
        }
        static c(a) {
            WebFilteringOperandDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:NumberFilteringOperand");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebNumberFilteringOperandDescriptionMetadata.b(a);
            a.ae("WebNumberFilteringOperand", () => new WebNumberFilteringOperandDescription());
            a.ad("WebNumberFilteringOperand", WebNumberFilteringOperandDescriptionMetadata.a);
        }
    }
    WebNumberFilteringOperandDescriptionMetadata.$t = markType(WebNumberFilteringOperandDescriptionMetadata, 'WebNumberFilteringOperandDescriptionMetadata');
    WebNumberFilteringOperandDescriptionMetadata.a = null;
    return WebNumberFilteringOperandDescriptionMetadata;
})();
